#!/usr/bin/env node

const fs = require('fs');
const path = require('path');
const stream = require('stream');
const stdin = require('get-stdin');
const minimist = require('minimist');
const filesize = require('filesize');
const chalk = require('chalk');

const imgo = require('.');
const argv = minimist(process.argv.slice(2), {
  alias: {
    h: 'help',
    i: 'info',
    v: 'version',
    j: 'jpg',
    p: 'png',
    g: 'gif',
    s: 'svg'
  }
});

process.stdout.on('error', process.exit);

if (argv.h || argv.help) {
  fs.createReadStream(path.join(__dirname, '/usage.txt'))
    .pipe(process.stdout)
    .on('close', () => process.exit(1));
} else if (argv.v || argv.version) {
  console.log(require('./package.json').version);
} else {
  const options = Object.assign({}, argv);

  if (options.j || options.jpg) {
    options.mozjpeg = true;
    options.jpegoptim = true;
    options.jpegRecompress = true;
  }

  if (options.p || options.png) {
    options.pngquant = true;
    options.pngcrush = true;
    options.optipng = true;
    options.zopflipng = true;
  }

  if (options.g || options.gif) {
    options.gifsicle = true;
  }

  if (options.s || options.svg) {
    options.svgo = true;
  }

  let before = 0;
  let after = 0;
  stdin.buffer()
    .then(buffer => {
      before = buffer.length;

      return imgo(buffer, options);
    })
    .then(buffer => {
      after = buffer.length;

      const bufferStream = new stream.PassThrough();
      bufferStream.end(buffer);
      bufferStream.pipe(process.stdout);

      if (argv.i || argv.info) {
        console.error(
          chalk.gray(' before=') + chalk.yellow(filesize(before)) +
          chalk.gray(' after=') + chalk.cyan(filesize(after)) +
          chalk.gray(' reduced=') + chalk.green.underline(filesize(after - before))
        );
      }
    });
}
